@@ -25,23 +25,26 @@ var List = []list.Item{
 	ExtractEmails{},
 	ExtractIPs{},
 	FormatJSON{},
-	HTMLDecode{},
-	HTMLEncode{},
 	HexDecode{},
 	HexEncode{},
 	HexToRGB{},
+	HTMLDecode{},
+	HTMLEncode{},
 	JSONEscape{},
 	JSONToMSGPACK{},
 	JSONToYAML{},
 	JSONUnescape{},
 	Kebab{},
 	Lower{},
+	Markdown{},
 	MD5{},
 	MSGPACKToJSON{},
-	Markdown{},
-	ROT13Encode{},
+	RemoveNewLines{},
+	RemoveSpaces{},
 	Reverse{},
 	ReverseLines{},
+	ReverseLines{},
+	ROT13Encode{},
 	SHA1{},
 	SHA256{},
 	SHA512{},
@@ -50,10 +53,10 @@ var List = []list.Item{
 	Snake{},
 	SortLines{},
 	Title{},
-	URLDecode{},
-	URLEncode{},
 	UniqueLines{},
 	Upper{},
+	URLDecode{},
+	URLEncode{},
 	YAMLToJSON{},
 	Zeropad{},
 }
